CmdCtxTypes

Trait CmdCtxTypes 

pub trait CmdCtxTypes {
    type AppError: Debug;
    type Output;
    type ParamsKeys: ParamsKeys;
}
Trait so that a single type parameter can be used in CmdCtx and Scopes.

The associated types linked to the concrete type can all be queried through this trait.

Required Associated Types

type AppError: Debug

Error type of the automation software.

type Output

Output to write progress or outcome to.

type ParamsKeys: ParamsKeys

Parameter key types for workspace params, profile params, and flow params.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<AppError, Output, ParamsKeysT> CmdCtxTypes for CmdCtxTypesCollector<AppError, Output, ParamsKeysT>
where AppError: Debug, ParamsKeysT: ParamsKeys,

Source

type AppError = AppError

Source

type Output = Output

Source

type ParamsKeys = ParamsKeysT