MultiProfileNoFlow

Struct MultiProfileNoFlow 

pub struct MultiProfileNoFlow<'ctx, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,
{ /* private fields */ }
A command that works with multiple profiles, not scoped to a flow.

path/to/repo/.peace/envman
|- 📝 workspace_params.yaml    # ✅ can read or write `WorkspaceParams`
|
|- 🌏 internal_dev_a           # ✅ can list multiple `Profile`s
|   |- 📝 profile_params.yaml  # ✅ can read multiple `ProfileParams`
|   |
|   |- ..                      # ❌ cannot read or write `Flow` information
|
|- 🌏 customer_a_dev           # ✅
|   |- 📝 profile_params.yaml  # ✅
|
|- 🌏 customer_a_prod          # ✅
|   |- 📝 profile_params.yaml  # ✅
|
|- 🌏 workspace_init           # ✅ can list multiple `Profile`s
    |- 📝 profile_params.yaml  # ❌ cannot read profile params of different underlying type

Capabilities

This kind of command can:

  • Read or write workspace parameters.
  • Read or write multiple profiles’ parameters – as long as they are of the same type (same struct).

This kind of command cannot:

  • Read or write flow parameters – see MultiProfileNoFlow or MultiProfileSingleFlow.
  • Read or write flow state – see MultiProfileNoFlow or MultiProfileSingleFlow.

Implementations

Source

impl<'ctx, CmdCtxTypesT> MultiProfileNoFlow<'ctx, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,

pub fn view(&mut self) -> MultiProfileNoFlowView<'_, CmdCtxTypesT>

Returns a view struct of this scope.

pub fn output(&self) -> &CmdCtxTypesT::Output

Returns a reference to the output.

pub fn output_mut(&mut self) -> &mut CmdCtxTypesT::Output

Returns a mutable reference to the output.

pub fn interruptibility_state(&mut self) -> InterruptibilityState<'_, '_>

Returns the interruptibility capability.

pub fn workspace(&self) -> &Workspace

Returns the workspace that the peace tool runs in.

pub fn workspace_dir(&self) -> &WorkspaceDir

Returns a reference to the workspace directory.

pub fn peace_dir(&self) -> &PeaceDir

Returns a reference to the .peace directory.

pub fn peace_app_dir(&self) -> &PeaceAppDir

Returns a reference to the .peace/$app directory.

pub fn profiles(&self) -> &[Profile]

Returns the accessible profiles.

These are the profiles that are filtered by the filter function, if provided.

pub fn profile_dirs(&self) -> &BTreeMap<Profile, ProfileDir>

Returns the profile directories keyed by each profile.

pub fn profile_history_dirs(&self) -> &BTreeMap<Profile, ProfileHistoryDir>

Returns the profile history directories keyed by each profile.

pub fn params_type_regs(&self) -> &ParamsTypeRegs<CmdCtxTypesT::ParamsKeys>

Returns the type registries for WorkspaceParams, ProfileParams, and FlowParams deserialization.

Source

impl<CmdCtxTypesT, WorkspaceParamsK, ProfileParamsKMaybe, FlowParamsKMaybe> MultiProfileNoFlow<'_, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes<ParamsKeys = ParamsKeysImpl<KeyKnown<WorkspaceParamsK>, ProfileParamsKMaybe, FlowParamsKMaybe>>, WorkspaceParamsK: Clone + Debug + Eq + Hash + DeserializeOwned + Serialize + Send + Sync + Unpin + 'static, ProfileParamsKMaybe: KeyMaybe, FlowParamsKMaybe: KeyMaybe,

pub fn workspace_params(&self) -> &WorkspaceParams<WorkspaceParamsK>

Returns the workspace params.

Source

impl<CmdCtxTypesT, WorkspaceParamsKMaybe, ProfileParamsK, FlowParamsKMaybe> MultiProfileNoFlow<'_, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes<ParamsKeys = ParamsKeysImpl<WorkspaceParamsKMaybe, KeyKnown<ProfileParamsK>, FlowParamsKMaybe>>, WorkspaceParamsKMaybe: KeyMaybe, ProfileParamsK: Clone + Debug + Eq + Hash + DeserializeOwned + Serialize + Send + Sync + Unpin + 'static, FlowParamsKMaybe: KeyMaybe,

pub fn profile_to_profile_params( &self, ) -> &BTreeMap<Profile, ProfileParams<ProfileParamsK>>

Returns the profile params for each profile.