SingleProfileSingleFlow

Struct SingleProfileSingleFlow 

pub struct SingleProfileSingleFlow<'ctx, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,
{ /* private fields */ }
A command that works with one profile and one flow.

path/to/repo/.peace/envman
|- 📝 workspace_params.yaml    # ✅ can read or write `WorkspaceParams`
|
|- 🌏 internal_dev_a
|   |- 📝 profile_params.yaml  # ✅ can read or write `ProfileParams`
|   |
|   |- 🌊 deploy                # ✅ can read `FlowId`
|   |   |- 📝 flow_params.yaml  # ✅ can read or write `FlowParams`
|   |   |- 📋 states_goal.yaml  # ✅ can read or write `StatesGoal`
|   |   |- 📋 states_current.yaml # ✅ can read or write `StatesCurrentStored`
|   |
|   |- 🌊 ..                   # ❌ cannot read or write other `Flow` information
|
|- 🌏 ..                       # ❌ cannot read or write other `Profile` information

Capabilities

This kind of command can:

  • Read or write workspace parameters.
  • Read or write a single profile’s parameters. For multiple profiles, see MultiProfileNoFlow.

This kind of command cannot:

  • Read or write flow parameters – see MultiProfileNoFlow.
  • Read or write flow state – see SingleProfileSingleFlow or MultiProfileSingleFlow.

Implementations

Source

impl<CmdCtxTypesT> SingleProfileSingleFlow<'_, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,

pub fn view(&mut self) -> SingleProfileSingleFlowView<'_, CmdCtxTypesT>

Returns a view struct of this scope.

This allows the flow and resources to be borrowed concurrently.

pub fn view_and_output( &mut self, ) -> SingleProfileSingleFlowViewAndOutput<'_, CmdCtxTypesT>

Returns a view and output struct of this scope.

This allows the flow and resources to be borrowed concurrently.

pub fn output(&self) -> &CmdCtxTypesT::Output

Returns a reference to the output.

pub fn output_mut(&mut self) -> &mut CmdCtxTypesT::Output

Returns a mutable reference to the output.

pub fn interruptibility_state(&mut self) -> InterruptibilityState<'_, '_>

Returns the interruptibility capability.

pub fn workspace(&self) -> &Workspace

Returns the workspace that the peace tool runs in.

pub fn workspace_dir(&self) -> &WorkspaceDir

Returns a reference to the workspace directory.

pub fn peace_dir(&self) -> &PeaceDir

Returns a reference to the .peace directory.

pub fn peace_app_dir(&self) -> &PeaceAppDir

Returns a reference to the .peace/$app directory.

pub fn profile(&self) -> &Profile

Returns a reference to the profile.

pub fn profile_dir(&self) -> &ProfileDir

Returns a reference to the profile directory.

pub fn profile_history_dir(&self) -> &ProfileHistoryDir

Returns a reference to the profile history directory.

pub fn flow(&self) -> &Flow<CmdCtxTypesT::AppError>

Returns a reference to the flow.

pub fn flow_dir(&self) -> &FlowDir

Returns a reference to the flow directory.

pub fn params_type_regs(&self) -> &ParamsTypeRegs<CmdCtxTypesT::ParamsKeys>

Returns the type registries for WorkspaceParams, ProfileParams, and FlowParams deserialization.

pub fn params_specs_type_reg(&self) -> &ParamsSpecsTypeReg

Returns the type registry for each item’s Params::Spec.

This is used to deserialize ParamsSpecsFile.

pub fn params_specs(&self) -> &ParamsSpecs

Returns the item params specs for the selected flow.

pub fn states_type_reg(&self) -> &StatesTypeReg

Returns the type registry for each item’s State.

This is used to deserialize StatesCurrentFile and StatesGoalFile.

pub fn resources(&self) -> &Resources<SetUp>

Returns a reference to the Resources for flow execution.

pub fn resources_mut(&mut self) -> &mut Resources<SetUp>

Returns a reference to the Resources for flow execution.

Source

impl<CmdCtxTypesT, WorkspaceParamsK, ProfileParamsKMaybe, FlowParamsKMaybe> SingleProfileSingleFlow<'_, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes<ParamsKeys = ParamsKeysImpl<KeyKnown<WorkspaceParamsK>, ProfileParamsKMaybe, FlowParamsKMaybe>>, WorkspaceParamsK: Clone + Debug + Eq + Hash + DeserializeOwned + Serialize + Send + Sync + Unpin + 'static, ProfileParamsKMaybe: KeyMaybe, FlowParamsKMaybe: KeyMaybe,

pub fn workspace_params(&self) -> &WorkspaceParams<WorkspaceParamsK>

Returns the workspace params.

Source

impl<CmdCtxTypesT, WorkspaceParamsKMaybe, ProfileParamsK, FlowParamsKMaybe> SingleProfileSingleFlow<'_, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes<ParamsKeys = ParamsKeysImpl<WorkspaceParamsKMaybe, KeyKnown<ProfileParamsK>, FlowParamsKMaybe>>, WorkspaceParamsKMaybe: KeyMaybe, ProfileParamsK: Clone + Debug + Eq + Hash + DeserializeOwned + Serialize + Send + Sync + Unpin + 'static, FlowParamsKMaybe: KeyMaybe,

pub fn profile_params(&self) -> &ProfileParams<ProfileParamsK>

Returns the profile params.

Source

impl<CmdCtxTypesT, WorkspaceParamsKMaybe, ProfileParamsKMaybe, FlowParamsK> SingleProfileSingleFlow<'_, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes<ParamsKeys = ParamsKeysImpl<WorkspaceParamsKMaybe, ProfileParamsKMaybe, KeyKnown<FlowParamsK>>>, WorkspaceParamsKMaybe: KeyMaybe, ProfileParamsKMaybe: KeyMaybe, FlowParamsK: Clone + Debug + Eq + Hash + DeserializeOwned + Serialize + Send + Sync + Unpin + 'static,

pub fn flow_params(&self) -> &FlowParams<FlowParamsK>

Returns the flow params.