pub trait CmdCtxTypes {
type AppError: Debug;
type Output;
type ParamsKeys: ParamsKeys;
}Expand description
Trait so that a single type parameter can be used in CmdCtx and Scopes.
The associated types linked to the concrete type can all be queried through this trait.
Required Associated Types
Sourcetype ParamsKeys: ParamsKeys
type ParamsKeys: ParamsKeys
Parameter key types for workspace params, profile params, and flow params.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".